[![CI](https://github.com/DiamondLightSource/velocity-profile/actions/workflows/ci.yml/badge.svg)](https://github.com/DiamondLightSource/velocity-profile/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/DiamondLightSource/velocity-profile/branch/main/graph/badge.svg)](https://codecov.io/gh/DiamondLightSource/velocity-profile)
[![PyPI](https://img.shields.io/pypi/v/velocity-profile.svg)](https://pypi.org/project/velocity-profile)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# velocity_profile

Module for calculating velocity profile

Source          | <https://github.com/DiamondLightSource/velocity-profile>
:---:           | :---:
PyPI            | `pip install velocity-profile`
Releases        | <https://github.com/DiamondLightSource/velocity-profile/releases>
